# tokelor
![PyPI](https://img.shields.io/pypi/v/tokelor) 
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/tokelor)
![License](https://img.shields.io/github/license/lensvol/tokelor)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Visualize Python token stream produced by tokenize module.

## Example

![Example usage](https://raw.githubusercontent.com/lensvol/tokelor/master/docs/example.png)

## Usage
```
# tokelor --help
Usage: tokelor [OPTIONS] SOURCE

  Visualize Python token stream produced by tokenize module.

Options:
  --nl / --no-nl      Display newline tokens.
  --bare / --no-bare  Replace bold text with underlinings.
  --help              Show this message and exit.
```

## Installation

```shell script
# pip install tokelor
```

## Getting started with development

```shell script
# git clone git@github.com:lensvol/tokelor.git
# poetry install --develop
```

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details

## Authors

* **Kirill Borisov** ([lensvol@gmail.com](mailto:lensvol@gmail.com))
